==> haskell-tasty-quickcheck-0.10.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10.1
id: tasty-quickcheck-0.10.1-DGd2sdFbrRyEntoJoamYJ5
key: tasty-quickcheck-0.10.1-DGd2sdFbrRyEntoJoamYJ5
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: 1611f7d2d6f29992b12db7372f1d4f2c
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-quickcheck-0.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-quickcheck-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-quickcheck-0.10.1
hs-libraries: HStasty-quickcheck-0.10.1-DGd2sdFbrRyEntoJoamYJ5
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW base-4.12.0.0
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10.1
id: tasty-quickcheck-0.10.1-OXI7PIGAtTAWOzueT18x8
key: tasty-quickcheck-0.10.1-OXI7PIGAtTAWOzueT18x8
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: 029fad6a2f1261d3462ae345bd42a686
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-quickcheck-0.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-quickcheck-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-quickcheck-0.10.1
hs-libraries: HStasty-quickcheck-0.10.1-OXI7PIGAtTAWOzueT18x8
depends:
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW base-4.12.0.0
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
